Welcome to Dpowers' documentation!
===================================

Source code:
`<https://github.com/dp0s/Dpowers>`_


Introduction
************

.. include:: intro.rst


Requirements
*************
- python 3.6 or later
- Currently only tested on apt based Linux systems (Debian, Ubuntu, Linux Mint).


.. toctree::
   :maxdepth: 2
   :caption: Preperation

   preperation

.. toctree::
   :maxdepth: 2
   :caption: Quickstart

   quickstart

.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Reference (still incomplete)

   reference/*



Indices and tables
******************

* :ref:`genindex`


